# Security Review Checklist
\n+- Dependency audit (`scripts/dependency_audit.sh`)
- SBOM generation (`scripts/sbom_diff.sh`)
- License policy verification (`scripts/license_check.sh`)
- CVE thresholds aligned with `policies/security.yaml`



